IMAXT Image Utilities
=====================

Installation
------------

We recomment to install the IMAXT software in a Conda environment with Python 3.7 and a few numerical Python libraries. The command below will create such environment::

    conda create -n imaxt python=3.7 numpy scipy zarr xarray dask distributed

To install `imaxt-image` activate the created environment and use pip::

    conda activate imaxt
    pip install imaxt-image



